( cd usr/bin ; rm -rf thunderbird )
( cd usr/bin ; ln -sf /usr/lib/thunderbird-1.0.6/thunderbird thunderbird )
( cd usr/lib ; rm -rf thunderbird )
( cd usr/lib ; ln -sf thunderbird-1.0.6 thunderbird )
